Enum Reason
#[non_exhaustive]#[repr(u32)]pub enum Reason {
Launch = 1,
Recover = 2,
SessionRestore = 3,
}Available on crate feature
wayland and Linux only.Expand description
reason for getting a session
The reason may determine in what way a session restores the window management state of associated toplevels.
For example newly launched applications might be launched on the active workspace with restored size and position, while a recovered applications might restore additional state such as active workspace and stacking order.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Launch = 1
an app is newly launched
A new app instance is launched, for example from an app launcher.
Recover = 2
an app recovered
A app instance is recovering from for example a compositor or app crash.
SessionRestore = 3
an app restored
A app instance is restored, for example part of a restored session, or restored from having been temporarily terminated due to resource constraints.