Struct XxSessionManagerV1
pub struct XxSessionManagerV1 { /* private fields */ }wayland and Linux only.Expand description
manage sessions for applications
The xx_session_manager interface defines base requests for creating and managing a session for an application. Sessions persist across application and compositor restarts unless explicitly destroyed. A session is created for the purpose of maintaining an application’s xdg_toplevel surfaces across compositor or application restarts. The compositor should remember as many states as possible for surfaces in a given session, but there is no requirement for which states must be remembered.
This interface has no events.
Implementations
impl XxSessionManagerV1
impl XxSessionManagerV1
pub fn destroy(&self)
pub fn destroy(&self)
Destroy this object
This has no effect other than to destroy the xx_session_manager object.
pub fn get_session<U, D>(
&self,
reason: Reason,
session: Option<String>,
qh: &QueueHandle<D>,
udata: U,
) -> XxSessionV1
pub fn get_session<U, D>( &self, reason: Reason, session: Option<String>, qh: &QueueHandle<D>, udata: U, ) -> XxSessionV1
create or restore a session
Create a session object corresponding to either an existing session identified by the given session identifier string or a new session. While the session object exists, the session is considered to be “in use”.
If a identifier string represents a session that is currently actively in use by the the same client, an ‘in_use’ error is raised. If some other client is currently using the same session, the new session will replace managing the associated state.
NULL is passed to initiate a new session. If an id is passed which does not represent a valid session, the compositor treats it as if NULL had been passed.
A client is allowed to have any number of in use sessions at the same time.